@@ -1,16 +1,16 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
     generate portrait landscape
     north east south west handson
-    layout checkerboard animate
+    layout checkerboard scroll
     chess checkers conway sudoku
     calculator calendar banner maze
-    beadwork
+    beadwork animate
 );
 
 use HTML::AutoTag;
@@ -36,7 +36,8 @@ sub tictactoe       { Spreadsheet::HTML::Presets::TicTacToe::tictactoe( @_ ) }
 sub sudoku          { Spreadsheet::HTML::Presets::Sudoku::sudoku(   @_ ) }
 sub checkerboard    { Spreadsheet::HTML::Presets::checkerboard(     @_ ) }
 sub calendar        { Spreadsheet::HTML::Presets::calendar(         @_ ) }
-sub animate         { Spreadsheet::HTML::Presets::Animate::animate( @_ ) }
+sub scroll          { Spreadsheet::HTML::Presets::Scroll::scroll(   @_ ) }
+sub animate         { Spreadsheet::HTML::Presets::Scroll::animate(  @_ ) }
 sub maze            { Spreadsheet::HTML::Presets::maze(             @_ ) }
 sub banner          { Spreadsheet::HTML::Presets::banner(           @_ ) }
 sub beadwork        { Spreadsheet::HTML::Presets::Beadwork::beadwork( @_ ) }
@@ -86,7 +87,12 @@ sub generate {
     }
 
     if ($args{animate}) {
-        my ($js, %new_args) = Spreadsheet::HTML::Presets::Animate::animate(
+        warn "animate is deprecated, use scroll instead\n";
+        $args{scroll} = delete $args{animate};
+    }
+
+    if ($args{scroll}) {
+        my ($js, %new_args) = Spreadsheet::HTML::Presets::Scroll::scroll(
             %args,
             data => [ map [ map $_->{cdata}, @$_ ], @{ $args{data} } ],
         );
@@ -144,7 +150,10 @@ sub _process {
                 ( $cdata, $attr ) = _extrapolate( $cdata, $attr, $args->{$_} );
             }
 
-            do{ no warnings; $cdata =~ s/^\s*$/$empty/g };
+            do{ no warnings;
+                $cdata = HTML::Entities::encode_entities( $cdata, $args->{encodes} ) if $args->{encode} || exists $args->{encodes};
+                $cdata =~ s/^\s*$/$empty/g;
+            };
 
             $data->[$row][$col] = { 
                 tag => $tag, 
@@ -277,7 +286,6 @@ sub _args {
     $data = delete $args->{data} if exists $args->{data};
 
     $args->{_auto} = HTML::AutoTag->new(
-        encodes => exists $args->{encodes} ? $args->{encodes} : '',
         indent  => $args->{indent},
         level   => $args->{level},
         sorted  => $args->{sorted_attrs},
@@ -597,13 +605,18 @@ to insert into to.
 This value does not say 'use 4 spaces', it applies the
 repetition operator to the value of C<indent> 4 times.
 
+=item * C<encode>
+
+Encode HTML entities. Boolean. Defaults to false, which produces no encoding.
+If set to true without further specifying a value for C<encodes> (see below),
+will encode all control chars, high bit chars and '<', '&', '>', ''' and '"'.
+
+  encode => 1
+
 =item * C<encodes>
 
-HTML Encode contents of <th> and/or <td> tags. Defaults to
-empty string which performs no encoding of entities. Pass
-a string like '<>&=' to perform encoding on any characters
-found.  If the value is C<undef> then all unsafe characters
-will be encoded as HTML entites. Uses L<HTML::Entities>.
+Encode HTML entities. String. Set value to those characters you wish to
+have encoded.
 
   encodes => '<>"'
 
@@ -648,7 +661,7 @@ Render the table with without the headings row at all.
 The first row after the headings is still C<-r1>, and
 any configuration to C<headings> or C<-r0> will be discarded.
 
-=item * C<animate: 0 or 1>
+=item * C<scroll: 0 or 1>
 
 Animate the table cells. See L<Spreadsheet::HTML::Presets::Animate>.
 
@@ -830,8 +843,12 @@ with little to no additional coding.
 
 =item * C<calendar( month, year, %params )>
 
+=item * C<scroll( fgdirection, bgdirection, jquery, %params )>
+
 =item * C<animate( fgdirection, bgdirection, jquery, %params )>
 
+Deprecated. Use C<scroll> instead.
+
 =item * C<conway( on, off, fade, jquery, %params )>
 
 =item * C<calculator( jquery, %params )>
